## Preventing files from being scanned for provides (pre-scan filtering) 
%{?filter_setup:
%filter_provides_in %{_libdir}/ascend/models/.*\.so$
%filter_provides_in %{_libdir}/ascend/solvers/.*\.so$
%filter_setup
}

%global gtksourceview_lang_file %{_datadir}/gtksourceview-3.0/language-specs/ascend.lang
%global johnpye %{_libdir}/ascend/models/johnpye
%global models %{_libdir}/ascend/models

Name:		ascend
Summary:	ASCEND modelling environment
Version:	0.9.8
Release:	15.20140710svn4695%{?dist}
License:	GPLv2+
URL:		http://ascend4.org/

## Source archive from svn #4695; obtained by:
## svn co svn://ascend4.org/code/trunk ascend
## tar -czvf  ascend-svn4695.tar.gz ascend
Source0: %{name}-svn4695.tar.gz

##Fix building optimization flags 
Patch0:  %{name}-optflags.patch

## error: expected identifier or '(' before 'extension'
Patch1:  %{name}-mmio.patch

##Define libraries directory
Patch2:  %{name}-libpaths.patch

##This patch is needed to compile IDA solver with sundials-2.5.0
##http://bugs.ascend4.org/view.php?id=559
Patch3:  %{name}-idasolver.patch 


#------ build dependencies -------
BuildRequires: scons >= 0.96.92
BuildRequires: bison
BuildRequires: flex >= 2.5.4
BuildRequires: swig >= 1.3.24
BuildRequires: gcc-gfortran >= 4
BuildRequires: blas-devel
BuildRequires: sundials-devel >= 2.4.0
BuildRequires: coin-or-Ipopt-devel >= 3.11.9-1
BuildRequires: MUMPS-devel >= 4.10.0-21
BuildRequires: graphviz-devel
BuildRequires: python2-devel
BuildRequires: desktop-file-utils
BuildRequires: swig >= 2.0.1

#-------build dependencies for tests
BuildRequires: CUnit-devel

# ...pygtk
Requires: pygtk2 >= 2.6
Requires: pygtk2-libglade
Requires: python-matplotlib
Requires: numpy
Requires: ipython

# syntax highlighting for gedit
Requires: gtksourceview3

Requires: coin-or-Ipopt%{?_isa} >= 3.11.9-1
Requires: MUMPS%{?_isa} >= 4.10.0-21
Requires: graphviz%{?_isa}

Requires: %{name}-libs%{?_isa} = %{version}-%{release}
Requires: %{name}-data%{?_isa} = %{version}-%{release}

%description
ASCEND IV is both a large-scale object-oriented mathematical
modeling environment and a strongly typed mathematical modeling
language. Although ASCEND has primarily been developed by Chemical
Engineers, great care has been exercised to assure that it is
domain independent. ASCEND can support modeling activities in
fields from Architecture to (computational) Zoology.

%package libs
Summary: Ascend libraries
Requires: %{name} = %{version}-%{release}
%description libs
%{summary}.

%package devel
Summary: Ascend header files
Requires: %{name}-libs%{?_isa} = %{version}-%{release}
%description devel
Developer files for ASCEND, in the form for C header files for the core
ASCEND library, 'libascend'.

%package data
Summary: Ascend data files
Requires: %{name} = %{version}-%{release}
%description data
Ascend code for library models and example models.
Files have 5 extensions:

.a4s:  A Script (tcl) for loading in the ASCEND script window.
.a4l:  A library of reusable models. Each library contains enough
       test models to be self-validating and self-documenting.
.a4c:  Model code examples and demos.
.a4v:  A file of saved values from a simulation.
.tcl:  Auxillary TCL scripts for performing miscellaneous tasks
       related to modeling that the user may wish to copy and
       modify: for example, the user can create many permutations
       on the set_intervals.tcl functions which specify a
       time sampling schedule for the integrators.

#%%package tcltk
#Summary: Tcl/Tk user interface for ASCEND
#Requires: %%{name}-libs%%{?_isa} = %%{version}-%%{release}
#Requires: tcl >= 8.4
#Requires: tk >= 8.4

#%%description tcltk
#Tcl/Tk user interface for ASCEND. This is the original ASCEND IV interface
#and is a more complete and mature interface than the alternative PyGTK
#interface. Use this interface if you need to use ASCEND *.a4s files or other
#functionality not provided by the PyGTK interface. 


#%%package doc
#Summary: Documentation for ASCEND
#Group: Applications/Engineering
#BuildArch: noarch
#%%description doc
#Documentation for ASCEND, in the form of a PDF User's Manual.

%prep
%setup -q -n %{name}
%patch0 -p0
%patch1 -p0
%patch2 -p0
%patch3 -p0

sed -e 's|@@lib@@|%{_lib}|g' -i SConstruct
sed -e 's|@@libdir@@|%{_libdir}|g' -i SConstruct
sed -e 's|@@OPTFLAGS@@|%{optflags}|g' -i SConstruct

mv models/johnpye/fprops/README.txt models/johnpye/fprops/README-fprops.txt
mv models/johnpye/grena/README.txt models/johnpye/grena/README-grena.txt
mv models/README.txt models/README-models.txt
mv models/johnpye/fprops/test/README.txt models/johnpye/fprops/test/README-fpropstest.txt
mv models/test/link/README.txt models/test/link/README-DanteStroeLINK.txt

%build
scons %{?_smp_mflags} \
 INSTALL_ROOT=%{buildroot} \
 INSTALL_PREFIX=%{_prefix} \
 INSTALL_SHARE=%{_datadir} \
 INSTALL_BIN=%{_bindir} \
 INSTALL_INCLUDE=%{_includedir} \
 INSTALL_LIB=%{_libdir} \
 DEBUG=1 \
 WITH_DOC_BUILD=no \
 WITH_DOC_INSTALL=no \
 WITH_PYTHON=yes \
 WITH_TCLTK=no \
 WITH_GRAPHVIZ=yes \
 IPOPT_CPPPATH=%{_includedir}/coin \
 IPOPT_LIBPATH=%{_libdir} \
 IPOPT_LIBS="-L%{_libdir} -lipopt -ldmumps -lblas -llapack" \
 WITH_CUNIT=yes \
 CUNIT_CPPPATH=%{_includedir}/CUnit \
 CUNIT_LIBPATH=%{_libdir} \
 CUNIT_PREFIX=%{_prefix} \
 SUNDIALS_CPPPATH=%{_includedir} \
 SUNDIALS_LIBPATH=%{_libdir} \
 WITH_SOLVERS=QRSLV,LSODE,LRSLV,DOPRI5,IDA,IPOPT \
 ABSOLUTE_PATHS=no \
 ascend ascxx pygtk models solvers

%install
scons PREFIX=%{_prefix} LIBDIR=%{_libdir} install


# Install menu entry for PyGTK interface, gtksourceview syntax highlighting, and MIME definition
pushd pygtk/gnome
install -p -m 644 -D %{name}.desktop %{buildroot}/%{_datadir}/applications/%{name}.desktop
install -p -m 644 -D %{name}.png %{buildroot}/%{_datadir}/icons/%{name}-app.png
install -p -m 644 -D %{name}.png %{buildroot}/%{_datadir}/icons/hicolor/64x64/%{name}.png
install -p -m 644 -D %{name}.xml %{buildroot}/%{_datadir}/mime/packages/%{name}.xml
popd

# file-type icon for ascend models (double click should open in ASCEND)
pushd pygtk/glade
install -p -m 644 -D %{name}-doc-48x48.svg %{buildroot}/%{_datadir}/icons/text-x-%{name}-model.svg
popd

# language file for use with gedit
pushd tools/gtksourceview-2.0
install -p -m 644 -D %{name}.lang %{buildroot}/%{gtksourceview_lang_file}
popd

# Install menu entry for Tcl/Tk interface
pushd tcltk/gnome
install -p -m 644 -D %{name}4.desktop %{buildroot}/%{_datadir}/applications/%{name}4.desktop
install -p -m 644 -D %{name}4.png %{buildroot}/%{_datadir}/icons/%{name}4-app.png
install -p -m 644 -D %{name}4.png %{buildroot}/%{_datadir}/icons/hicolor/64x64/%{name}4.png
popd

##Tricks
# Fix .desktop files entries
desktop-file-install                                    \
 --set-icon=ascend-app                                  \
 --remove-key=Encoding                                  \
%{buildroot}/%{_datadir}/applications/%{name}.desktop

desktop-file-install                                    \
 --set-icon=ascend4-app                                  \
 --remove-key=Encoding                                  \
 --set-key=Exec --set-value="env ASCENDTK=%{_datadir}/%{name}/tcltk %{name}4" \
%{buildroot}/%{_datadir}/applications/%{name}4.desktop

# Fixed execute permission
pushd %{buildroot}/%{_libdir}
 for i in `find . -perm /644 -type f \( -name "*.so" -o -name "*.sh" -o -name "*.py" \)`; do
 chmod a+x $i
done
popd

pushd %{buildroot}%{python2_sitearch}
 for i in `find . -perm /644 -type f \( -name "*.so" -o -name "*.py" \)`; do
 chmod a+x $i
done
popd

chmod a+x %{buildroot}/%{_libdir}/libascend.so.1.0

for file in %{buildroot}%{johnpye}/fprops/test/{ph,sat,sat1,ideal}; do
   chmod a+x $file
done

rm %{buildroot}%{johnpye}/fprops/*README*
rm %{buildroot}%{johnpye}/datareader/*README.txt
rm %{buildroot}%{johnpye}/grena/README*
rm %{buildroot}%{johnpye}/fprops/test/*.txt
rm %{buildroot}%{models}/test/link/*.txt
##Tricks end

%post libs -p /sbin/ldconfig
%postun libs -p /sbin/ldconfig

%post
update-desktop-database &> /dev/null || :
update-mime-database /usr/share/mime &> /dev/null || :
touch --no-create %{_datadir}/icons/hicolor &>/dev/null || :

%postun
update-desktop-database &> /dev/null || :
update-mime-database /usr/share/mime &> /dev/null || :
if [ $1 -eq 0 ] ; then
    touch --no-create %{_datadir}/icons/hicolor &>/dev/null
    gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :
fi

%posttrans
gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :

%files
%doc LICENSE.txt CHANGELOG.txt
%{_bindir}/%{name}
%dir %{johnpye}/fprops/test
%{johnpye}/fprops/test/ph
%{johnpye}/fprops/test/sat
%{johnpye}/fprops/test/sat1
%{johnpye}/fprops/test/ideal
%{gtksourceview_lang_file}
%{python2_sitearch}/%{name}/
%dir  %{_datadir}/%{name}
%{_datadir}/%{name}/glade/
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/%{name}-app.png
%{_datadir}/icons/hicolor/64x64/%{name}.png
%{_datadir}/icons/text-x-%{name}-model.svg
%{_datadir}/mime/packages/%{name}.xml
%{_datadir}/applications/%{name}4.desktop
%{_datadir}/icons/%{name}4-app.png
%{_datadir}/icons/hicolor/64x64/%{name}4.png

%files libs
%dir %{_libdir}/%{name}
%{_libdir}/%{name}/solvers/*.so
%{_libdir}/libascend.so.1.0
%{_libdir}/libascend.so.1
%dir %{models}
%dir %{models}/sensitivity
%{models}/sensitivity/*.so
%dir %{models}/test
%dir %{models}/test/blackbox
%{models}/test/blackbox/libbboxtest_%{name}.so
%dir %{johnpye}
%dir %{johnpye}/grena
%{johnpye}/grena/libsunpos_%{name}.so
%dir %{johnpye}/extpy
%{johnpye}/extpy/libextpy_%{name}.so
%dir %{johnpye}/extfn
%{johnpye}/extfn/libextfntest_%{name}.so
%dir %{johnpye}/datareader
%{johnpye}/datareader/libdatareader_%{name}.so
%dir %{johnpye}/brent
%{johnpye}/brent/libbrent_%{name}.so
%dir %{johnpye}/nrel
%{johnpye}/nrel/libsunpos_nrel_%{name}.so
%dir %{johnpye}/fprops
%{johnpye}/fprops/libfprops_ascend.so
%{johnpye}/fprops/libheatex_pinch_ascend.so
%{python2_sitearch}/*fprops.*

%files devel
%{_bindir}/%{name}-config
%{_includedir}/%{name}/
%{_libdir}/libascend.so
%{johnpye}/datareader/*.[hc]
%{johnpye}/datareader/parse/*.[hc]
%{johnpye}/nrel/*.[hc]
%{johnpye}/brent/*.c
%{johnpye}/grena/*.[hc]
%{johnpye}/extfn/*.c
%{johnpye}/extpy/*.c
%{models}/test/blackbox/*.c
%{models}/sensitivity/*.c

%files data
%doc models/README* models/johnpye/fprops/README-fprops.txt
%doc models/johnpye/grena/README-grena.txt
%doc models/johnpye/datareader/texttable-README.txt
%doc models/johnpye/fprops/test/README-fpropstest.txt
%doc models/test/link/README-DanteStroeLINK.txt
%dir %{models}
%{models}/*.a4[lc]
%{models}/examples
%{models}/kchittur
%{models}/pending
%{models}/steam
%{models}/test/*/*/*.py
%{models}/test/*/*/*.py[oc]
%{models}/test/*/*/*.a4c
%{models}/test/*/*.py
%{models}/test/*/*.py[oc]
%{models}/test/*/*.a4c
%{models}/test/*.a4[cs]
%{models}/test/ipopt/MD5Hash
%{models}/westerberg
%{models}/solar
%{models}/libraries
%{models}/hydrosim
%{models}/ivpNondimensional
%{models}/ben
%dir %{johnpye}
%{johnpye}/fprops/*.a4c
%{johnpye}/fprops/*.py
%{johnpye}/fprops/*.py[oc]
%{johnpye}/fprops/calcs/
%{johnpye}/fprops/fluids/
%{johnpye}/fprops/scons/
%{johnpye}/fprops/Doxyfile
%{johnpye}/fprops/test/
%{johnpye}/grena/*.a4c
%{johnpye}/grena/grena-date-check.ods
%{johnpye}/extpy/*.a4c
%{johnpye}/extpy/*.py
%{johnpye}/extpy/*.py[oc]
%{johnpye}/extfn/*.a4c
%{johnpye}/extfn/*.py
%{johnpye}/extfn/*.py[oc]
%{johnpye}/datareader/*.a4c
%{johnpye}/datareader/*.py
%{johnpye}/datareader/*.py[oc]
%{johnpye}/datareader/*.csv
%{johnpye}/nrel/*.a4c
%{johnpye}/*.py[oc]
%{johnpye}/*.csv
%{johnpye}/*.a4c
%{johnpye}/*.py

#%%files tcltk
#%%{_bindir}/%%{name}4
#%%{_libdir}/libascendtcl.so
#%%{_datadir}/%%{name}/tcltk/
#%%{_datadir}/applications/%%{name}4.desktop
#%%{_datadir}/icons/%%{name}4-app.png
#%%{_datadir}/icons/hicolor/64x64/%%{name}4.png

#%%files doc
#%%doc doc/book.pdf

%changelog
* Fri Sep 05 2014 Antonio Trande <sagitter@fedoraproject.org> 0.9.8-15.20140710svn4695
- Changed Ipopt and MUMPS minimal requests

* Fri Sep 05 2014 Antonio Trande <sagitter@fedoraproject.org> 0.9.8-14.20140710svn4695
- Rebuild after bz#1135728 fixing

* Sun Aug 24 2014 Antonio Trande <sagitter@fedoraproject.org> 0.9.8-13.20140710svn4695
- Rebuild after Ipopt and MUMPS updating

* Mon Aug 18 2014 Rex Dieter <rdieter@fedoraproject.org> 0.9.8-12.20140710svn4695
- update mime scriptlets

* Fri Aug 15 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.9.8-11.20140710svn4695
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Thu Jul 10 2014 Antonio Trande <sagitter@fedoraproject.org> 0.9.8-10.20140710svn4695
- Update to new commit (4695)
- Fixed Graphviz 'cgraph' support 

* Tue Jun 24 2014 Antonio Trande <sagitter@fedoraproject.org> 0.9.8-9.20140623svn4683
- Update to new commit (4683)

* Fri Jun 20 2014 Antonio Trande <sagitter@fedoraproject.org> 0.9.8-8.20140429svn4677
- Added explicit dependencies (MUMPS, coin-or-Ipopt, graphviz)

* Sun Jun 08 2014 Antonio Trande <sagitter@fedoraproject.org> 0.9.8-7.20140429svn4677
- Rebuild after Sundials fixing (bz#1105767)

* Tue Jun 03 2014 Antonio Trande <sagitter@fedoraproject.org> 0.9.8-6.20140211svn4638
- Added patch for Swig checking

* Wed May 28 2014 Antonio Trande <sagitter@fedoraproject.org> 0.9.8-5.20140211svn4638
- Fixed sub-package dependencies
- Fixed %%post/%%postun scriptlets for -libs
- URL changed

* Mon Feb 24 2014 Antonio Trande <sagitter@fedoraproject.org> 0.9.8-4.20140211svn4638
- Excluded CMSLV solver
- Included IDA solver option with patch

* Tue Feb 18 2014 Antonio Trande <sagitter@fedoraproject.org> 0.9.8-3.20140211svn4638
- Built a 'libs' sub-package
- Fixed some directory ownerships
- Removed all Group tags
- Added -p options to all 'install' commands
- Added python2-devel BR
- Removed Requires(post/postun) 

* Wed Feb 12 2014 Antonio Trande <sagitter@fedoraproject.org> 0.9.8-2.20140211svn4638
- 'data' sub-package is now arched

* Tue Feb 11 2014 Antonio Trande <sagitter@fedoraproject.org> 0.9.8-1.20140211svn4638
- Update to svn4638 
- Built a 'data' sub-package

* Sat Dec 07 2013 Antonio Trande <sagitter@fedoraproject.org> 0.9.8-1.20131207svn4618
- Removed Tcl/Tk subpackage building because of missing dependencies
  (tktable) 
- Defined two macros for the packaging
- Defined the scriplets in %%post, %%postun, %%posttrans
- Patching compiler flags
- Added CUnit-devel BR and performing Ascend test
- IDA solver excluded

* Sun May 12 2013 Antonio Trande <sagitter@fedoraproject.org> 0.9.8-5
- Removed xgraph as Requires 

* Wed Mar 13 2013 Antonio Trande <sagitter@fedoraproject.org> 0.9.8-4
- doc sub-package changed to noarch
 
* Tue Feb 05 2013 Antonio Trande <sagitter@fedoraproject.org> 0.9.8-3
- Ipopt BuildRequires/Requires changed to coin-or-Ipopt
- Rearranged .h/.c files in %%{_libdir}/%%{name} as devel files

* Tue Feb 05 2013 Antonio Trande <sagitter@fedoraproject.org> 0.9.8-2
- Fixed .desktop files entries for EPEL6

* Thu Jan 24 2013 Antonio Trande <sagitter@fedoraproject.org> 0.9.8-1
- Fixed .desktop files entries for Fedora
- Fixed execute permission of various file
- Fixed non-executable-script warnings

* Thu Jan 24 2013 Antonio Trande <sagitter@fedoraproject.org> 0.9.8-0
- Initial package
